Re-exports
pub use app::HttpServer;pub use app::HttpsServer;pub use sark_json as json;
Modules
- app
- driver
- error
- fs
- Asynchronous static-file serving with bounded caching and single-flight loading.
- http
- listener
- middleware
- request
- routes
- service
- tcp
- utils
Macros
Structs
- Balanced
- Balanced defaults suitable for general production services.
- Empty
State - Executor
- LowLatency
- Favors low tail latency over batching and resource density.
- Tcp
- Throughput
- Favors sustained throughput and larger transfer batches.
- Timer
Traits
- Runtime
Profile - Application-level timing and admission policy layered on a driver profile.
- Timer
Host